@@ -25,7 +25,9 @@ describe(JekyllFeed) do
   let(:contents) { File.read(dest_dir("feed.xml")) }
   let(:context)  { make_context(:site => site) }
   let(:feed_meta) { Liquid::Template.parse("{% feed_meta %}").render!(context, {}) }
+  let(:jekyll_env) { "development" }
   before(:each) do
+    allow(Jekyll).to receive(:env).and_return(jekyll_env)
     site.process
   end
 
@@ -76,7 +78,7 @@ describe(JekyllFeed) do
   end
 
   it "converts markdown posts to HTML" do
-    expect(contents).to match %r!&lt;p&gt;March the second\!&lt;/p&gt;!
+    expect(contents).to match %r!<\!\[CDATA\[<p>March the second\!</p>\]\]!
   end
 
   it "uses last_modified_at where available" do
@@ -150,6 +152,11 @@ describe(JekyllFeed) do
       expect(post.summary.content).to eql("Foo")
     end
 
+    it "includes the item's description" do
+      post = feed.items[-2]
+      expect(post.summary.content).to eql("cool post")
+    end
+
     it "doesn't include the item's excerpt if blank" do
       post = feed.items.first
       expect(post.summary).to be_nil
@@ -392,10 +399,11 @@ describe(JekyllFeed) do
     context "with top-level post categories" do
       let(:overrides) do
         {
-          "feed" => { "categories" => ["news"] },
+          "feed" => { "categories" => %w(news jekyll) },
         }
       end
-      let(:news_feed) { File.read(dest_dir("feed/news.xml")) }
+      let(:singular_category_feed) { File.read(dest_dir("feed/news.xml")) }
+      let(:plural_categories_feed) { File.read(dest_dir("feed/jekyll.xml")) }
 
       it "outputs the primary feed" do
         expect(contents).to match "http://example.org/updates/jekyll/2014/03/04/march-the-fourth.html"
@@ -405,12 +413,13 @@ describe(JekyllFeed) do
         expect(contents).to_not match "http://example.org/2016/02/09/a-draft.html"
       end
 
-      it "outputs the category feed" do
-        expect(news_feed).to match '<title type="html">My awesome site | News</title>'
-        expect(news_feed).to match "http://example.org/news/2014/03/02/march-the-second.html"
-        expect(news_feed).to match "http://example.org/news/2013/12/12/dec-the-second.html"
-        expect(news_feed).to_not match "http://example.org/updates/jekyll/2014/03/04/march-the-fourth.html"
-        expect(news_feed).to_not match "http://example.org/2015/08/08/stuck-in-the-middle.html"
+      it "outputs the category feeds" do
+        expect(singular_category_feed).to match '<title type="html">My awesome site | News</title>'
+        expect(singular_category_feed).to match "http://example.org/news/2014/03/02/march-the-second.html"
+        expect(singular_category_feed).to match "March the second!"
+        expect(plural_categories_feed).to match '<title type="html">My awesome site | News</title>'
+        expect(plural_categories_feed).to match "http://example.org/updates/jekyll/2014/03/04/march-the-fourth.html"
+        expect(plural_categories_feed).to match "March the fourth!"
       end
     end
 
@@ -738,4 +747,30 @@ describe(JekyllFeed) do
       end
     end
   end
+
+  context "with skip_development" do
+    let(:overrides) do
+      {
+        "feed" => {
+          "disable_in_development" => true
+        },
+      }
+    end
+
+    context "in production environment" do
+      let(:jekyll_env) { "production" }
+
+      it "generates a feed as normal" do
+        expect(Pathname.new(dest_dir("feed.xml"))).to exist
+      end
+    end
+
+    context "in development environment" do
+      let(:jekyll_env) { "development" }
+
+      it "does not generate a feed" do
+        expect(Pathname.new(dest_dir("feed.xml"))).not_to exist
+      end
+    end
+  end
 end
